@@ -24,19 +24,19 @@
 
 #include "ktoolinvocation.h"
 
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <kmimetypetrader.h>
 
-#include "kconfig.h"
-#include "kshell.h"
-#include "kmacroexpander.h"
-#include "klocalizedstring.h"
-#include "kmessage.h"
+#include <KConfig>
+#include <KShell>
+#include <KMacroExpander>
+#include <KLocalizedString>
+#include <KMessage>
 #include "kservice.h"
 
 #include <QDebug>
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 #include <QHash>
 #include <QUrl>
 #include <QUrlQuery>
@@ -125,18 +125,11 @@ void KToolInvocation::invokeMailer(const QString &_to, const QString &_cc, const
     if (!isMainThreadActive()) {
         return;
     }
-
-    KConfig config(QStringLiteral("emaildefaults"));
-    KConfigGroup defaultsGrp(&config, "Defaults");
-
-    QString group = defaultsGrp.readEntry("Profile", "Default");
-
-    KConfigGroup profileGrp(&config, QStringLiteral("PROFILE_%1").arg(group));
-    QString command = profileGrp.readPathEntry("EmailClient", QString());
+    KService::Ptr emailClient = KMimeTypeTrader::self()->preferredService(QStringLiteral("x-scheme-handler/mailto"));
+    auto command = emailClient->exec();
 
     QString to, cc, bcc;
-    if (command.isEmpty() || command == QLatin1String("kmail")
-            || command.endsWith(QLatin1String("/kmail"))) {
+    if (emailClient->storageId() == QStringLiteral("org.kde.kmail2.desktop")) {
         command = QStringLiteral("kmail --composer -s %s -c %c -b %b --body %B --attach %A -- %t");
         if (!_to.isEmpty()) {
             QUrl url;
@@ -165,7 +158,7 @@ void KToolInvocation::invokeMailer(const QString &_to, const QString &_cc, const
         }
     }
 
-    if (profileGrp.readEntry("TerminalClient", false)) {
+    if (emailClient->terminal()) {
         KConfigGroup confGroup(KSharedConfig::openConfig(), "General");
         QString preferredTerminal = confGroup.readPathEntry("TerminalApplication", QStringLiteral("konsole"));
         command = preferredTerminal + QLatin1String(" -e ") + command;
@@ -249,6 +242,7 @@ void KToolInvocation::invokeMailer(const QString &_to, const QString &_cc, const
     }
 }
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
 void KToolInvocation::invokeBrowser(const QString &url, const QByteArray &startup_id)
 {
     if (!isMainThreadActive()) {
@@ -342,8 +336,10 @@ void KToolInvocation::invokeBrowser(const QString &url, const QByteArray &startu
                           i18n("Could not launch Browser"));
     }
 }
+#endif
 
 void KToolInvocation::invokeTerminal(const QString &command,
+                                     const QStringList &envs,
                                      const QString &workdir,
                                      const QByteArray &startup_id)
 {
@@ -376,9 +372,16 @@ void KToolInvocation::invokeTerminal(const QString &command,
 
     QString error;
     if (self()->startServiceInternal("kdeinit_exec_with_workdir",
-                                     cmd, cmdTokens, &error, nullptr, nullptr, startup_id, false, workdir)) {
+                                     cmd, cmdTokens, envs, &error, nullptr, nullptr, startup_id, false, workdir)) {
         KMessage::message(KMessage::Error,
                           i18n("Could not launch the terminal client:\n\n%1", error),
                           i18n("Could not launch Terminal Client"));
     }
 }
+
+void KToolInvocation::invokeTerminal(const QString &command,
+                                     const QString &workdir,
+                                     const QByteArray &startup_id)
+{
+    invokeTerminal(command, {}, workdir, startup_id);
+}
