@@ -41,21 +41,21 @@
 #include <QDebug>
 #include <QDirIterator>
 #include <QDateTime>
-#include <qsavefile.h>
+#include <QSaveFile>
 
 #include <kmemfile_p.h>
 
 #include <qplatformdefs.h>
 #include <time.h>
 #include <memory> // auto_ptr
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 #include <QLockFile>
 
 static const char *s_cSycocaPath = nullptr;
 
 KBuildSycocaInterface::~KBuildSycocaInterface() {}
 
-KBuildSycoca::KBuildSycoca(bool globalDatabase)
+KBuildSycoca::KBuildSycoca()
     : KSycoca(true),
       m_allEntries(nullptr),
       m_currentFactory(nullptr),
@@ -65,7 +65,6 @@ KBuildSycoca::KBuildSycoca(bool globalDatabase)
       m_serviceGroupEntryDict(nullptr),
       m_vfolder(nullptr),
       m_newTimestamp(0),
-      m_globalDatabase(globalDatabase),
       m_menuTest(false),
       m_changed(false)
 {
@@ -250,10 +249,6 @@ bool KBuildSycoca::build()
                 }
             }
         }
-        if (m_changed || !m_allEntries) {
-            //qCDebug(SYCOCA) << "CHANGED:" << m_resource;
-            m_changedResources.append(QString::fromLatin1(m_resource));
-        }
     }
 
     bool result = true;
@@ -293,10 +288,6 @@ bool KBuildSycoca::build()
             }
         }
 
-        if (m_changed || !m_allEntries) {
-            //qCDebug(SYCOCA) << "CHANGED:" << m_resource;
-            m_changedResources.append(QString::fromLatin1(m_resource));
-        }
         if (m_menuTest) {
             result = false;
         }
@@ -305,11 +296,6 @@ bool KBuildSycoca::build()
     if (m_ctimeDict && !m_ctimeDict->isEmpty()) {
         qCDebug(SYCOCA) << "Still in time dict:";
         m_ctimeDict->dump();
-
-        // Get the list of resources from which some files were deleted
-        QStringList resources = m_ctimeDict->remainingResourceList();
-        qCDebug(SYCOCA) << "Still in the time dict (i.e. deleted files)" << resources;
-        m_changedResources += resources;
     }
 
     qDeleteAll(entryDictList);
@@ -325,7 +311,7 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
 
         QString directoryFile = subMenu->directoryFile;
         if (directoryFile.isEmpty()) {
-            directoryFile = subName + QStringLiteral(".directory");
+            directoryFile = subName + QLatin1String(".directory");
         }
         quint32 timeStamp = m_ctimeFactory->dict()->ctime(directoryFile, m_resource);
         if (!timeStamp) {
@@ -375,7 +361,7 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
 
 bool KBuildSycoca::recreate(bool incremental)
 {
-    QFileInfo fi(KSycoca::absoluteFilePath(m_globalDatabase ? KSycoca::GlobalDatabase : KSycoca::LocalDatabase));
+    QFileInfo fi(KSycoca::absoluteFilePath());
     if (!QDir().mkpath(fi.absolutePath())) {
         qCWarning(SYCOCA) << "Couldn't create" << fi.absolutePath();
         return false;
@@ -386,7 +372,7 @@ bool KBuildSycoca::recreate(bool incremental)
     if (!lockFile.tryLock()) {
         qCDebug(SYCOCA) <<  "Waiting for already running" << KBUILDSYCOCA_EXENAME << "to finish.";
         if (!lockFile.lock()) {
-            qCWarning(SYCOCA) << "Couldn't lock" << path + QStringLiteral(".lock");
+            qCWarning(SYCOCA) << "Couldn't lock" << path + QLatin1String(".lock");
             return false;
         }
         if (!needsRebuild()) {
@@ -465,23 +451,21 @@ bool KBuildSycoca::recreate(bool incremental)
 #endif
 
         if (!database.commit()) {
-            qCWarning(SYCOCA) << "ERROR writing database" << database.fileName() << ". Disk full?";
+            qCWarning(SYCOCA) << "ERROR writing database" << database.fileName() << database.errorString();
             return false;
         }
 
-        if (!m_globalDatabase) {
-            // Compatibility code for KF < 5.15: provide a ksycoca5 symlink after the filename change, for old apps to keep working during the upgrade
-            const QString oldSycoca = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QLatin1String("/ksycoca5");
-            if (QFile::exists(oldSycoca)) {
-                QFile::remove(oldSycoca);
+        // Compatibility code for KF < 5.15: provide a ksycoca5 symlink after the filename change, for old apps to keep working during the upgrade
+        const QString oldSycoca = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QLatin1String("/ksycoca5");
+        if (QFile::exists(oldSycoca)) {
+            QFile::remove(oldSycoca);
 #ifdef Q_OS_UNIX
-                if (::link(QFile::encodeName(path).constData(), QFile::encodeName(oldSycoca).constData()) != 0) {
-                    QFile::copy(path, oldSycoca);
-                }
-#else
+            if (::link(QFile::encodeName(path).constData(), QFile::encodeName(oldSycoca).constData()) != 0) {
                 QFile::copy(path, oldSycoca);
-#endif
             }
+#else
+            QFile::copy(path, oldSycoca);
+#endif
         }
     } else {
         delete str;
@@ -493,13 +477,6 @@ bool KBuildSycoca::recreate(bool incremental)
         qCDebug(SYCOCA) << "Database is up to date";
     }
 
-    if (m_globalDatabase) {
-        // These directories may have been created with 0700 permission
-        // better delete them if they are empty
-        QString appsDir = QStandardPaths::writableLocation(QStandardPaths::ApplicationsLocation);
-        QDir().remove(appsDir);
-        // was doing the same with servicetypes, but I don't think any of these gets created-by-mistake anymore.
-    }
     if (d->m_sycocaStrategy == KSycocaPrivate::StrategyMemFile) {
         KMemFile::fileContentsChanged(path);
     }
